Installation
===============

.. hint:: 

    - Author: `Yifan Feng (丰一帆) <https://fengyifan.site/>`_
    - Proof: Xinwei Zhang

- Python >= 3.8
- Pytorch >= 1.12

Current, the stable version of **DHG** is 0.9.5. You can install it with ``pip`` as follows:

.. code-block:: bash

    pip install dhg

You can also try the nightly version (0.9.6) of **DHG** library with ``pip`` as follows:

.. code-block:: bash

    pip install git+https://github.com/iMoonLab/DeepHypergraph.git

.. note:: 
    
    Nightly version is the development version of **DHG**. It may include the lastest SOTA methods and datasets, but it can also be unstable and not fully tested. 
    If you find any bugs, please report it to us in `GitHub Issues <https://github.com/iMoonLab/DeepHypergraph/issues>`_.
